/*!
 * smarta
 * Copyright(c) 2011 Hidden <zzdhidden@gmail.com>
 * MIT Licensed
 */

var smarta = module.exports
	, dgram = require('dgram');

/**
 * Library version.
 */

smarta.version = require(__dirname + "/../package.json")['version'];

/**
 * Smarta Sensor Object
 *
 * //Create a sensor:
 * var sensor = new smarta.sensor("NodeJS"); //Default host:127.0.0.1, port: 7070
 * //Create a sensor with host and port:
 * var sensor = new smarta.sensor("NodeJS", "127.0.0.1", 7080);
 *
 * @param {String} name
 * @param {String} host optional
 * @param {String} port optional
 *
 * @return sensor
 */

smarta.sensor = function(name, host, port) {
	this.name = name || "NodeJS";
	this.host = host || "127.0.0.1";
	this.port = +port || 7070;
	this.client = dgram.createSocket("udp4");
};

/**
 *
 * Send message
 *
 * //Info message
 * sensor.info("I have sent 30 messages today.");
 *
 * //Warning message
 * sensor.warn("The messages are too more from Jack");
 *
 * //CRITICAL message
 * sensor.crit("Failed to send message to Jack");
 *
 * @param {String} title
 * @param {String} message
 *
 */

smarta.sensor.prototype.info = function(title, msg) {
	return this.send(1, title, msg);
};

smarta.sensor.prototype.warn = function(title, msg) {
	return this.send(2, title, msg);
};

smarta.sensor.prototype.crit = function(title, msg) {
	return this.send(3, title, msg);
};
var keys = [ "OK", "INFO", "WARNING", "CRITICAL" ];
smarta.sensor.prototype.send = function(severity, title, msg) {
	var text = ["sensor/p "];
	text.push(severity);
	text.push(" #");
	text.push(this.name);
	text.push("#");
	text.push(severity == 1 ? "" : ( " " + keys[severity] ));
	text.push("\n");
	text.push(title || "");
	text.push("\n\n");
	text.push(msg || "");
	//console.log( text.join("") );
	msg = new Buffer( text.join("") );
	var client = this.client;
	client.send(msg, 0, msg.length, this.port, this.host, function(err, bytes) {
	});
	return this;
};

smarta.sensor.prototype.close = function(title, msg) {
	this.client.close();
};
